@@ -35,25 +35,25 @@ public:
     explicit ThemeManager(const QString &themeType, const QString &defaultDesktopFileName, KActionCollection *actionCollection = nullptr, const QString &path = QString(), QObject *parent = nullptr);
     ~ThemeManager();
 
-    QMap<QString, GrantleeTheme::Theme> themes() const;
+    Q_REQUIRED_RESULT QMap<QString, GrantleeTheme::Theme> themes() const;
 
     void setActionGroup(QActionGroup *actionGroup);
 
-    KToggleAction *actionForTheme();
+    Q_REQUIRED_RESULT KToggleAction *actionForTheme();
 
     void setThemeMenu(KActionMenu *menu);
 
-    QStringList displayExtraVariables(const QString &themename) const;
+    Q_REQUIRED_RESULT QStringList displayExtraVariables(const QString &themename) const;
 
-    GrantleeTheme::Theme theme(const QString &themeName);
+    Q_REQUIRED_RESULT GrantleeTheme::Theme theme(const QString &themeName);
 
     void setDownloadNewStuffConfigFile(const QString &configFileName);
 
-    QString configuredThemeName() const;
-    static QString configuredThemeName(const QString &themeType);
+    Q_REQUIRED_RESULT QString configuredThemeName() const;
+    Q_REQUIRED_RESULT static QString configuredThemeName(const QString &themeType);
 
-    static QString pathFromThemes(const QString &path, const QString &themeName, const QString &defaultDesktopFilename);
-    static GrantleeTheme::Theme loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFilename);
+    Q_REQUIRED_RESULT static QString pathFromThemes(const QString &path, const QString &themeName, const QString &defaultDesktopFilename);
+    Q_REQUIRED_RESULT static GrantleeTheme::Theme loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFilename);
 
 Q_SIGNALS:
     void themesChanged();
